@@ -3,9 +3,11 @@
 package Contact::GEN::BDay;
 
 use strict;
+use warnings;
 
 use base 'Contact';
 use JSON;
+use Gantry::Utils::TablePerms;
 
 use Contact::Model::bday qw(
     $BDAY
@@ -26,17 +28,19 @@ sub do_main {
         $real_location .= '/';
     }
 
+    my @header_options = (
+        {
+            text => 'Add',
+            link => $real_location . "add/$contact",
+            type => 'create',
+        },
+    );
+
     my $retval = {
         headings       => [
             'Contact',
             'Birth Day',
         ],
-        header_options => [
-            {
-                text => 'Add',
-                link => $real_location . "add/$contact",
-            },
-        ],
     };
 
     my %param = $self->get_param_hash;
@@ -59,6 +63,31 @@ sub do_main {
         } if scalar( @searches ) > 0;
     }
 
+    my @row_options = (
+        {
+            text => 'Edit',
+            type => 'update',
+        },
+        {
+            text => 'Delete',
+            type => 'delete',
+        },
+    );
+
+    my $perm_obj = Gantry::Utils::TablePerms->new(
+        {
+            site           => $self,
+            real_location  => $real_location,
+            header_options => \@header_options,
+            row_options    => \@row_options,
+        }
+    );
+
+    $retval->{ header_options } = $perm_obj->real_header_options;
+
+    my $limit_to_user_id = $perm_obj->limit_to_user_id;
+    $search->{ user_id } = $limit_to_user_id if ( $limit_to_user_id );
+
     if ( $contact ) {
         $search->{ contact } = $contact;
     }
@@ -71,27 +100,23 @@ sub do_main {
         }
     );
 
+    ROW:
     foreach my $row ( @rows ) {
+        last ROW if $perm_obj->hide_all_data;
+
         my $id = $row->id;
         my $contact = ( $row->contact )
                 ? $row->contact->foreign_display()
                 : '';
+
         push(
             @{ $retval->{rows} }, {
+                orm_row => $row,
                 data => [
                     $contact,
                     $row->bday,
                 ],
-                options => [
-                    {
-                        text => 'Edit',
-                        link => $real_location . "edit/$id",
-                    },
-                    {
-                        text => 'Delete',
-                        link => $real_location . "delete/$id",
-                    },
-                ],
+                options => $perm_obj->real_row_options( $row ),
             }
         );
     }
@@ -105,7 +130,7 @@ sub do_main {
             rows            => $retval->{ rows },
         };
 
-        my $json = objToJson( $obj );
+        my $json = objToJson( $obj, { skipinvalid => 1 } );
         return( $json );
     }
 
