@@ -3,9 +3,11 @@
 package Contact::GEN::Number;
 
 use strict;
+use warnings;
 
 use base 'Contact';
 use JSON;
+use Gantry::Utils::TablePerms;
 
 use Contact::Model::number qw(
     $NUMBER
@@ -26,21 +28,24 @@ sub do_main {
         $real_location .= '/';
     }
 
+    my @header_options = (
+        {
+            text => 'Add',
+            link => $real_location . "add",
+            type => 'create',
+        },
+        {
+            text => 'CSV',
+            link => $real_location . "csv",
+            type => 'create',
+        },
+    );
+
     my $retval = {
         headings       => [
             'Name',
             'Number',
         ],
-        header_options => [
-            {
-                text => 'Add',
-                link => $real_location . "add",
-            },
-            {
-                text => 'CSV',
-                link => $real_location . "csv",
-            },
-        ],
     };
 
     my %param = $self->get_param_hash;
@@ -63,6 +68,31 @@ sub do_main {
         } if scalar( @searches ) > 0;
     }
 
+    my @row_options = (
+        {
+            text => 'Edit',
+            type => 'update',
+        },
+        {
+            text => 'Delete',
+            type => 'delete',
+        },
+    );
+
+    my $perm_obj = Gantry::Utils::TablePerms->new(
+        {
+            site           => $self,
+            real_location  => $real_location,
+            header_options => \@header_options,
+            row_options    => \@row_options,
+        }
+    );
+
+    $retval->{ header_options } = $perm_obj->real_header_options;
+
+    my $limit_to_user_id = $perm_obj->limit_to_user_id;
+    $search->{ user_id } = $limit_to_user_id if ( $limit_to_user_id );
+
     my $page    = $param{ page } || 1;
 
     my $schema  = $self->get_schema();
@@ -78,24 +108,20 @@ sub do_main {
     $retval->{ page } = $results->pager();
     my $rows          = $results->page();
 
+    ROW:
     while ( my $row = $rows->next ) {
+        last ROW if $perm_obj->hide_all_data;
+
         my $id = $row->id;
+
         push(
             @{ $retval->{rows} }, {
+                orm_row => $row,
                 data => [
                     $row->name,
                     $row->number,
                 ],
-                options => [
-                    {
-                        text => 'Edit',
-                        link => $real_location . "edit/$id",
-                    },
-                    {
-                        text => 'Delete',
-                        link => $real_location . "delete/$id",
-                    },
-                ],
+                options => $perm_obj->real_row_options( $row ),
             }
         );
     }
@@ -109,7 +135,7 @@ sub do_main {
             rows            => $retval->{ rows },
         };
 
-        my $json = objToJson( $obj );
+        my $json = objToJson( $obj, { skipinvalid => 1 } );
         return( $json );
     }
 
